package AWS::Lambda;
use 5.026000;
use strict;
use warnings;

our $VERSION = "0.0.30";

# the context of Lambda Function
our $context;

# This list is auto generated by authors/update-aws-lambda.pl; DO NOT EDIT
our $LAYERS = {
    '5.34' => {
        'af-south-1' => {
            runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-east-1' => {
            runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-northeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-northeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-northeast-3' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-south-1' => {
            runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-southeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ap-southeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'ca-central-1' => {
            runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'eu-central-1' => {
            runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'eu-south-1' => {
            runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'eu-west-1' => {
            runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'eu-west-2' => {
            runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'eu-west-3' => {
            runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'me-south-1' => {
            runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'sa-east-1' => {
            runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'us-east-1' => {
            runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'us-east-2' => {
            runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'us-west-1' => {
            runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
        'us-west-2' => {
            runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime:4",
            runtime_version => 4,
            paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws:3",
            paws_version    => 3,
        },
    },
    '5.32' => {
        'af-south-1' => {
            runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ap-east-1' => {
            runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ap-northeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ap-northeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ap-northeast-3' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-paws:4",
            paws_version    => 4,
        },
        'ap-south-1' => {
            runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ap-southeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ap-southeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'ca-central-1' => {
            runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'eu-central-1' => {
            runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'eu-south-1' => {
            runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'eu-west-1' => {
            runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'eu-west-2' => {
            runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'eu-west-3' => {
            runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'me-south-1' => {
            runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'sa-east-1' => {
            runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'us-east-1' => {
            runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'us-east-2' => {
            runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'us-west-1' => {
            runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
        'us-west-2' => {
            runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime:6",
            runtime_version => 6,
            paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws:6",
            paws_version    => 6,
        },
    },
    '5.30' => {
        'af-south-1' => {
            runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-30-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-30-paws:6",
            paws_version    => 6,
        },
        'ap-east-1' => {
            runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-30-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'ap-northeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'ap-northeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-30-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'ap-northeast-3' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-30-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-30-paws:4",
            paws_version    => 4,
        },
        'ap-south-1' => {
            runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'ap-southeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'ap-southeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'ca-central-1' => {
            runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-30-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'eu-central-1' => {
            runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'eu-south-1' => {
            runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-30-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-30-paws:6",
            paws_version    => 6,
        },
        'eu-west-1' => {
            runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'eu-west-2' => {
            runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'eu-west-3' => {
            runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-30-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'me-south-1' => {
            runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-30-runtime:10",
            runtime_version => 10,
            paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-30-paws:9",
            paws_version    => 9,
        },
        'sa-east-1' => {
            runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-30-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'us-east-1' => {
            runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'us-east-2' => {
            runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'us-west-1' => {
            runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-30-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
        'us-west-2' => {
            runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-30-runtime:13",
            runtime_version => 13,
            paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-30-paws:10",
            paws_version    => 10,
        },
    },
    '5.28' => {
        'af-south-1' => {
            runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-28-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-28-paws:6",
            paws_version    => 6,
        },
        'ap-east-1' => {
            runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-28-runtime:11",
            runtime_version => 11,
            paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'ap-northeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'ap-northeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-28-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'ap-northeast-3' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-28-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-28-paws:4",
            paws_version    => 4,
        },
        'ap-south-1' => {
            runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'ap-southeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'ap-southeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'ca-central-1' => {
            runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-28-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'eu-central-1' => {
            runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'eu-south-1' => {
            runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-28-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-28-paws:6",
            paws_version    => 6,
        },
        'eu-west-1' => {
            runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'eu-west-2' => {
            runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'eu-west-3' => {
            runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-28-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'me-south-1' => {
            runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-28-runtime:9",
            runtime_version => 9,
            paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-28-paws:8",
            paws_version    => 8,
        },
        'sa-east-1' => {
            runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-28-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'us-east-1' => {
            runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'us-east-2' => {
            runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'us-west-1' => {
            runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-28-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
        'us-west-2' => {
            runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-28-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-28-paws:9",
            paws_version    => 9,
        },
    },
    '5.26' => {
        'af-south-1' => {
            runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-26-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-26-paws:6",
            paws_version    => 6,
        },
        'ap-east-1' => {
            runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-26-runtime:12",
            runtime_version => 12,
            paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'ap-northeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-26-runtime:20",
            runtime_version => 20,
            paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'ap-northeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-26-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'ap-northeast-3' => {
            runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-26-runtime:3",
            runtime_version => 3,
            paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-26-paws:4",
            paws_version    => 4,
        },
        'ap-south-1' => {
            runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-26-runtime:20",
            runtime_version => 20,
            paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'ap-southeast-1' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-26-runtime:20",
            runtime_version => 20,
            paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'ap-southeast-2' => {
            runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-26-runtime:20",
            runtime_version => 20,
            paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'ca-central-1' => {
            runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-26-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'eu-central-1' => {
            runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-26-runtime:20",
            runtime_version => 20,
            paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'eu-south-1' => {
            runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-26-runtime:5",
            runtime_version => 5,
            paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-26-paws:6",
            paws_version    => 6,
        },
        'eu-west-1' => {
            runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-26-runtime:20",
            runtime_version => 20,
            paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-26-paws:10",
            paws_version    => 10,
        },
        'eu-west-2' => {
            runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-26-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
        'eu-west-3' => {
            runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-26-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
        'me-south-1' => {
            runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-26-runtime:9",
            runtime_version => 9,
            paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-26-paws:8",
            paws_version    => 8,
        },
        'sa-east-1' => {
            runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-26-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
        'us-east-1' => {
            runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-26-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
        'us-east-2' => {
            runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-26-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
        'us-west-1' => {
            runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-26-runtime:18",
            runtime_version => 18,
            paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
        'us-west-2' => {
            runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-26-runtime:19",
            runtime_version => 19,
            paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-26-paws:9",
            paws_version    => 9,
        },
    },
};

our $LAYERS_AL2 = {
    '5.34' => {
        'x86_64' => {
            'af-south-1' => {
                runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-east-1' => {
                runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-northeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ap-northeast-2' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-northeast-3' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-south-1' => {
                runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ap-southeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ap-southeast-2' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ca-central-1' => {
                runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'eu-central-1' => {
                runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'eu-south-1' => {
                runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'eu-west-1' => {
                runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'eu-west-2' => {
                runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'eu-west-3' => {
                runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'me-south-1' => {
                runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'sa-east-1' => {
                runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'us-east-1' => {
                runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'us-east-2' => {
                runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'us-west-1' => {
                runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'us-west-2' => {
                runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2",
                paws_version    => 2,
            },
        },
        'arm64' => {
            'ap-northeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'ap-south-1' => {
                runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'ap-southeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'ap-southeast-2' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'eu-central-1' => {
                runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'eu-west-1' => {
                runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'eu-west-2' => {
                runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'us-east-1' => {
                runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'us-east-2' => {
                runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'us-west-2' => {
                runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws-al2-arm64:1",
                paws_version    => 1,
            },
        },
    },
    '5.32' => {
        'x86_64' => {
            'af-south-1' => {
                runtime_arn     => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-east-1' => {
                runtime_arn     => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-northeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ap-northeast-2' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-northeast-3' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'ap-south-1' => {
                runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ap-southeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ap-southeast-2' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'ca-central-1' => {
                runtime_arn     => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'eu-central-1' => {
                runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'eu-south-1' => {
                runtime_arn     => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'eu-west-1' => {
                runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'eu-west-2' => {
                runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'eu-west-3' => {
                runtime_arn     => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'me-south-1' => {
                runtime_arn     => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'sa-east-1' => {
                runtime_arn     => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'us-east-1' => {
                runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'us-east-2' => {
                runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
            'us-west-1' => {
                runtime_arn     => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1",
                paws_version    => 1,
            },
            'us-west-2' => {
                runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2",
                runtime_version => 2,
                paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2",
                paws_version    => 2,
            },
        },
        'arm64' => {
            'ap-northeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'ap-south-1' => {
                runtime_arn     => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'ap-southeast-1' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'ap-southeast-2' => {
                runtime_arn     => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'eu-central-1' => {
                runtime_arn     => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'eu-west-1' => {
                runtime_arn     => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'eu-west-2' => {
                runtime_arn     => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'us-east-1' => {
                runtime_arn     => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'us-east-2' => {
                runtime_arn     => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
            'us-west-2' => {
                runtime_arn     => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1",
                runtime_version => 1,
                paws_arn        => "arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws-al2-arm64:1",
                paws_version    => 1,
            },
        },
    },
};


sub get_layer_info {
    my ($version, $region) = @_;
    return $LAYERS->{$version}{$region};
}

sub print_runtime_arn {
    my ($version, $region) = @_;
    print $LAYERS->{$version}{$region}{runtime_arn};
}

sub print_paws_arn {
    my ($version, $region) = @_;
    print $LAYERS->{$version}{$region}{paws_arn};
}

sub get_layer_info_al2 {
    my ($version, $region, $arch) = @_;
    $arch //= 'x86_64';
    return $LAYERS_AL2->{$version}{$arch}{$region};
}

sub print_runtime_arn_al2 {
    my ($version, $region, $arch) = @_;
    $arch //= 'x86_64';
    print $LAYERS_AL2->{$version}{$arch}{$region}{runtime_arn};
}

sub print_paws_arn_al2 {
    my ($version, $region, $arch) = @_;
    $arch //= 'x86_64';
    print $LAYERS_AL2->{$version}{$arch}{$region}{paws_arn};
}

1;
__END__

=encoding utf-8

=head1 NAME

AWS::Lambda - It's Perl support for AWS Lambda Custom Runtime.

=head1 SYNOPSIS

Save the following Perl script as C<handler.pl>.

    sub handle {
        my ($payload, $context) = @_;
        return $payload;
    }
    1;

and then, zip the script.

    $ zip handler.zip handler.pl

Finally, create new function using awscli.

    $ aws --region "$REGION" --profile "$PROFILE" lambda create-function \
        --function-name "hello-perl" \
        --zip-file "fileb://handler.zip" \
        --handler "handler.handle" \
        --runtime provided.al2 \
        --role arn:aws:iam::xxxxxxxxxxxx:role/service-role/lambda-custom-runtime-perl-role \
        --layers "arn:aws:lambda:$REGION:445285296882:layer:perl-5-34-runtime-al2-x86_64:2"

=head1 DESCRIPTION

This package makes it easy to run AWS Lambda Functions written in Perl.

=head2 Use Pre-built Public Lambda Layers

=over

=item 1

Login to your AWS Account and go to the Lambda Console.

=item 2

Create a new function and give it a name and an IAM Role.

=item 3

For the "Runtime" selection, select B<Provide your own bootstrap on Amazon Linux 2>.

=item 4

In the "Designer" section of your function dashboard, select the B<Layers> box.

=item 5

Scroll down to the "Layers" section and click B<Add a layer>.

=item 6

Select the B<Provide a layer version ARN> option, then copy/paste the Layer ARN for your region.

=item 7

Click the B<Add> button.

=item 8

Click B<Save> in the upper right.

=item 9

Upload your code and start using Perl in AWS Lambda!

=back

You can get the layer ARN in your script by using C<get_layer_info>.

    use AWS::Lambda;
    my $info = AWS::Lambda::get_layer_info_al2(
        "5.34",      # Perl Version
        "us-east-1", # Region
        "x86_64",    # Architecture ("x86_64" or "arm64", optional, the default is "x86_64")
    );
    say $info->{runtime_arn};     # arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2
    say $info->{runtime_version}; # 2
    say $info->{paws_arn}         # arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2
    say $info->{paws_version}     # 2,

Or, you can use following one-liner.

    perl -MAWS::Lambda -e 'AWS::Lambda::print_runtime_arn_al2("5.34", "us-east-1")'
    perl -MAWS::Lambda -e 'AWS::Lambda::print_paws_arn_al2("5.34", "us-east-1")'

The list of all available layer ARN is here:

=over

=item Perl 5.34

=over

=item x86_64 architecture

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime-al2-x86_64:2>

=back

=item arm64 architecture

=over

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime-al2-arm64:1>

=back

=back

=item Perl 5.32

=over

=item x86_64 architecture

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-runtime-al2-x86_64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime-al2-x86_64:2>

=back

=item arm64 architecture

=over

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime-al2-arm64:1>

=back

=back

=back

=head2 Use Pre-built Zip Archives

=over

=item 1

Login to your AWS Account and go to the Lambda Console.

=item 2

Create a new layer and give it a name.

=item 3

For the "Code entry type" selection, select B<Upload a file from Amazon S3>.

=item 4

In the "License" section, input L<https://github.com/shogo82148/p5-aws-lambda/blob/main/LICENSE>.

=item 5

Click B<Create> button.

=item 6

Use the layer created. For detail, see Use Prebuilt Public Lambda Layer section.

=back

URLs for Zip archives are here.

C<https://shogo82148-lambda-perl-runtime-$REGION.s3.amazonaws.com/perl-$VERSION-runtime-al2-$ARCHITECTURE.zip>

=head2 Use Pre-built Docker Images

Prebuilt Docker Images based on L<https://gallery.ecr.aws/lambda/provided> are available.
You can pull from L<https://gallery.ecr.aws/shogo82148/p5-aws-lambda> or L<https://hub.docker.com/r/shogo82148/p5-aws-lambda>,
build your custom images and deploy them to AWS Lambda.

Here is an example of Dockerfile.

    FROM shogo82148/p5-aws-lambda:base-5.34.al2
    # or if you want to use ECR Public.
    # FROM public.ecr.aws/shogo82148/p5-aws-lambda:base-5.34.al2
    COPY handler.pl /var/task/
    CMD [ "handler.handle" ]

Build the hello-perl container image locally:

    $ docker build -t hello-perl .

To check if this is working, start the container image locally using the Lambda Runtime Interface Emulator:

    $ docker run -p 9000:8080 hello-perl:latest

Now, you can test a function invocation with cURL.

    $ curl -XPOST "http://localhost:9000/2015-03-31/functions/function/invocations" -d '{}'

To upload the container image, you need to create a new ECR repository in your account and tag the local image to push it to ECR.

    $ aws ecr create-repository --repository-name hello-perl --image-scanning-configuration scanOnPush=true
    $ docker tag hello-perl:latest 123412341234.dkr.ecr.sa-east-1.amazonaws.com/hello-perl:latest
    $ aws ecr get-login-password | docker login --username AWS --password-stdin 123412341234.dkr.ecr.sa-east-1.amazonaws.com
    $ docker push 123412341234.dkr.ecr.sa-east-1.amazonaws.com/hello-perl:latest

Finally, create new function using awscli.

    $ aws --region "$REGION" --profile "$PROFILE" lambda create-function \
        --function-name "hello-perl" \
        --code ImageUri=123412341234.dkr.ecr.sa-east-1.amazonaws.com/hello-perl:latest \
        --handler "handler.handle" \
        --runtime provided.al2 \
        --role arn:aws:iam::xxxxxxxxxxxx:role/service-role/lambda-custom-runtime-perl-role

=head2 Run in Local using Docker

Prebuilt Docker Images based on L<https://hub.docker.com/r/lambci/lambda/> are available.
You can pull from L<https://gallery.ecr.aws/shogo82148/p5-aws-lambda> or L<https://hub.docker.com/r/shogo82148/p5-aws-lambda>,
and build zip archives to deploy.

    # Install the dependency.
    docker run --rm -v $(PWD):/var/task shogo82148/p5-aws-lambda:build-5.34.al2 \
        cpanm --notest --local-lib extlocal --no-man-pages --installdeps .

    # run an event.
    docker run --rm -v $(PWD):/var/task shogo82148/p5-aws-lambda:5.34.al2 \
        handler.handle '{"some":"event"}'

=head2 Pre-installed modules

The following modules are pre-installed for convenience.

=over

=item L<AWS::Lambda>

=item L<AWS::XRay>

=item L<JSON>

=item L<Cpanel::JSON::XS>

=item L<JSON::MaybeXS>

=item L<YAML>

=item L<YAML::Tiny>

=item L<YAML::XS>

=item L<Net::SSLeay>

=item L<IO::Socket::SSL>

=item L<Mozilla::CA>

=back

L<Paws> is optional. See the "Paws SUPPORT" section.

=head2 AWS X-Ray SUPPORT

L<AWS X-Ray|https://aws.amazon.com/xray/> is a service that collects data about requests that your application serves.
You can trace AWS Lambda requests and sends segment data with pre-install module L<AWS::XRay>.

    use utf8;
    use warnings;
    use strict;
    use AWS::XRay qw/ capture /;

    sub handle {
        my ($payload, $context) = @_;
        capture "myApp" => sub {
            capture "nested" => sub {
                # do something ...
            };
        };
        capture "another" => sub {
            # do something ...
        };
        return;
    }

    1;


=head1 Paws SUPPORT

If you want to call AWS API from your Lambda function,
you can use a pre-built Lambda Layer for L<Paws> - A Perl SDK for AWS (Amazon Web Services) APIs.

=head2 Use Prebuilt Public Lambda Layers

Add the perl-runtime layer and the perl-paws layer into your lambda function.

    aws --region "$REGION" --profile "$PROFILE" lambda create-function \
        --function-name "hello-perl" \
        --zip-file "fileb://handler.zip" \
        --handler "handler.handle" \
        --runtime provided.al2 \
        --role arn:aws:iam::xxxxxxxxxxxx:role/service-role/lambda-custom-runtime-perl-role \
        --layers \
            "arn:aws:lambda:$REGION:445285296882:layer:perl-5-34-runtime-al2-x86_64:2" \
            "arn:aws:lambda:$REGION:445285296882:layer:perl-5-34-paws-al2-x86_64:2"

Now, you can use L<Paws> to call AWS API from your Lambda function.

    use Paws;
    my $obj = Paws->service('...');
    my $res = $obj->MethodCall(Arg1 => $val1, Arg2 => $val2);
    print $res->AttributeFromResult;

The list of all available layer ARN is here:

=over

=item Perl 5.34

=over

=item x86_64 architecture

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-paws-al2-x86_64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws-al2-x86_64:2>

=back

=item arm64 architecture

=over

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws-al2-arm64:1>

=back

=back

=item Perl 5.32

=over

=item x86_64 architecture

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-paws-al2-x86_64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws-al2-x86_64:2>

=back

=item arm64 architecture

=over

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws-al2-arm64:1>

=back

=back

=back

URLs for Zip archive are here.

C<https://shogo82148-lambda-perl-runtime-$REGION.s3.amazonaws.com/perl-$VERSION-paws-al2-$ARCHITECTURE.zip>

=head2 Use Prebuilt Docker Images for Paws

use the C<base-$VERSION-paws.al2> tag on L<https://gallery.ecr.aws/shogo82148/p5-aws-lambda> or L<https://hub.docker.com/r/shogo82148/p5-aws-lambda>.

    FROM shogo82148/p5-aws-lambda:base-5.34-paws.al2
    # or if you want to use ECR Public.
    # FROM public.ecr.aws/shogo82148/p5-aws-lambda:base-5.34-paws.al2
    COPY handler.pl /var/task/
    CMD [ "handler.handle" ]

=head2 Run in Local using Docker for Paws

use the C<build-$VERSION-paws.al2> and C<$VERSION-paws.al2> tag on L<https://gallery.ecr.aws/shogo82148/p5-aws-lambda> or L<https://hub.docker.com/r/shogo82148/p5-aws-lambda>.

    # Install the dependency.
    docker run --rm -v $(PWD):/var/task shogo82148/p5-aws-lambda:build-5.34-paws.al2 \
        cpanm --notest --local-lib extlocal --no-man-pages --installdeps .

    # run an event.
    docker run --rm -v $(PWD):/var/task shogo82148/p5-aws-lambda:5.34-paws.al2 \
        handler.handle '{"some":"event"}'

=head1 CREATE MODULE LAYER

To create custom module layer such as the Paws Layer,
install the modules into C</opt/lib/perl5/site_perl> in the layer.

    # Create Some::Module Layer
    docker run --rm \
        -v $(PWD):/var/task \
        -v $(PATH_TO_LAYER_DIR)/lib/perl5/site_perl:/opt/lib/perl5/site_perl \
        shogo82148/p5-aws-lambda:build-5.34.al2 \
        cpanm --notest --no-man-pages Some::Module
    cd $(PATH_TO_LAYER_DIR) && zip -9 -r $(PATH_TO_DIST)/some-module.zip .

=head1 LEGACY CUSTOM RUNTIME ON AMAZON LINUX

We also provide the layers for legacy custom runtime as known as "provided".
These layers are only for backward compatibility.
We recommend to migrate to Amazon Linux 2.
We may stop maintenance without any notice.

=head2 Pre-built Public Lambda Layers for Amazon Linux

The list of all available layer ARN is here:

=over

=item Perl 5.34

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime:4>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-runtime:3>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime:4>

=back

=item Perl 5.32

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-runtime:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime:6>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-runtime:5>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime:6>

=back

=item Perl 5.30

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-30-runtime:5>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-30-runtime:12>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-30-runtime:12>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-30-runtime:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-30-runtime:12>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-30-runtime:5>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-30-runtime:12>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-30-runtime:10>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-30-runtime:12>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-30-runtime:13>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-30-runtime:12>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-30-runtime:13>

=back

=item Perl 5.28

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-28-runtime:5>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-28-runtime:11>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-28-runtime:18>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-28-runtime:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-28-runtime:18>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-28-runtime:5>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-28-runtime:18>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-28-runtime:9>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-28-runtime:18>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-28-runtime:19>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-28-runtime:18>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-28-runtime:19>

=back

=item Perl 5.26

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-26-runtime:5>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-26-runtime:12>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-26-runtime:20>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-26-runtime:19>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-26-runtime:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-26-runtime:20>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-26-runtime:20>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-26-runtime:20>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-26-runtime:19>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-26-runtime:20>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-26-runtime:5>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-26-runtime:20>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-26-runtime:19>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-26-runtime:18>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-26-runtime:9>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-26-runtime:18>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-26-runtime:19>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-26-runtime:19>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-26-runtime:18>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-26-runtime:19>

=back

=back

And Paws layers:

=over

=item Perl 5.34

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-paws:3>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws:3>

=back

=item Perl 5.32

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-paws:4>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-paws:6>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws:6>

=back

=item Perl 5.30

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-30-paws:6>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-30-paws:4>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-30-paws:6>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-30-paws:9>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-30-paws:10>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-30-paws:10>

=back

=item Perl 5.28

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-28-paws:6>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-28-paws:4>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-28-paws:6>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-28-paws:8>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-28-paws:9>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-28-paws:9>

=back

=item Perl 5.26

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-26-paws:6>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-26-paws:4>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-26-paws:6>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-26-paws:10>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-26-paws:9>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-26-paws:9>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-26-paws:8>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-26-paws:9>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-26-paws:9>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-26-paws:9>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-26-paws:9>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-26-paws:9>

=back

=back

=head2 Pre-built Zip Archives for Amazon Linux

URLs of zip archives are here:

C<https://shogo82148-lambda-perl-runtime-$REGION.s3.amazonaws.com/perl-$VERSION-runtime.zip>

And Paws:

C<https://shogo82148-lambda-perl-runtime-$REGION.s3.amazonaws.com/perl-$VERSION-paws.zip>

=head1 LEGACY CUSTOM RUNTIME ON AMAZON LINUX 2

Previously, we provided the layers that named without CPU architectures.
These layers are compatible with x86_64 and only for backward compatibility.
We recommend to specify the CPU architecture.
We may stop maintenance without any notice.

=head2 Pre-built Legacy Public Lambda Layers for Amazon Linux 2

The list of all available layer ARN is here:

=over

=item Perl 5.34

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-runtime-al2:4>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-runtime-al2:3>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-runtime-al2:4>

=back

=item Perl 5.32

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-runtime-al2:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-runtime-al2:6>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-runtime-al2:5>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-runtime-al2:6>

=back

=back

And Paws layers:

=over

=item Perl 5.34

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-34-paws-al2:4>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-34-paws-al2:3>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-34-paws-al2:4>

=back

=item Perl 5.32

=over

=item C<arn:aws:lambda:af-south-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:ap-east-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:ap-northeast-1:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:ap-northeast-2:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:ap-northeast-3:445285296882:layer:perl-5-32-paws-al2:4>

=item C<arn:aws:lambda:ap-south-1:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:ap-southeast-1:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:ap-southeast-2:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:ca-central-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:eu-central-1:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:eu-south-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:eu-west-1:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:eu-west-2:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:eu-west-3:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:me-south-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:sa-east-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:us-east-1:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:us-east-2:445285296882:layer:perl-5-32-paws-al2:7>

=item C<arn:aws:lambda:us-west-1:445285296882:layer:perl-5-32-paws-al2:6>

=item C<arn:aws:lambda:us-west-2:445285296882:layer:perl-5-32-paws-al2:7>

=back

=back

=head2 Pre-built Legacy Zip Archives for Amazon Linux 2 x86_64

URLs of zip archives are here:

C<https://shogo82148-lambda-perl-runtime-$REGION.s3.amazonaws.com/perl-$VERSION-runtime-al2.zip>

And Paws:

C<https://shogo82148-lambda-perl-runtime-$REGION.s3.amazonaws.com/perl-$VERSION-paws-al2.zip>

=head1 SEE ALSO

=over

=item L<AWS::Lambda::Bootstrap>

=item L<AWS::Lambda::Context>

=item L<AWS::Lambda::PSGI>

=item L<Paws>

=item L<AWS::XRay>

=back

=head1 LICENSE

The MIT License (MIT)

Copyright (C) Ichinose Shogo

=head1 AUTHOR

Ichinose Shogo

=cut
